==> fap-0.9.0pre1.tar.bz2: fap-0.9.0pre1/src/audio/input/wvBackend.h <==
/*
 *  Copyright (C) 2007-2010 Leandro Nini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef WV_H
#define WV_H

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#ifdef HAVE_WAVPACK
extern "C" {
#include <wavpack/wavpack.h>
}

#include "inputBackend.h"
#include <fx.h>

/*****************************************************************/

#include "configFrame.h"

class wvConfig : public configFrame {
	FXDECLARE(wvConfig)

private:
	wvConfig() {};
	wvConfig(const wvConfig&);
	wvConfig& operator=(const wvConfig&);

public:
	wvConfig(FXPacker* win);
	virtual ~wvConfig() {};
};

/*****************************************************************/

class wvBackend : public inputBackend {

private:
	WavpackContext	*_wvContext;
	FXint		*_decodeBuf;
	FXint		_bufOffset;
	FXint		_bufSize;
	FXint		_bps;
	FXint		_channels;
	sample_t	_precision;

private:
	void copyBuffer(FXchar* dest, const FXint* src, size_t length);

public:
	wvBackend();
	~wvBackend();

	static const char name[];

	/// Factory method
	static input* factory() { return new wvBackend(); }

	/// Check if we support ext
	static bool supports(const char* fileName);

	/// Get supported extension
	FXString ext() const;

	/// Open file
	bool open(const FXString& fileName);

	/// Close file
	void close();

	/// Rewind to start
	const bool rewind();

	/// Get samplerate
	const unsigned int samplerate() const {
		return _wvContext?
			WavpackGetSampleRate(_wvContext):
			0;
	}

	/// Get channels
	const unsigned int channels() const {
		return _wvContext?
			WavpackGetReducedChannels(_wvContext):
			0;
	}

	/// Get precision
	const sample_t precision() const { return _precision; }

	/// Get fractional scale for fixed point types
	const unsigned int fract() const { return (_bps<<3)-1; }

	/// Callback function
	size_t fillBuffer(void* buffer, size_t bufferSize, unsigned int seconds);

	/// Gapless support
	const bool gapless() { return true; };

	/// Open config dialog
	void config(FXPacker* win) { new wvConfig(win); }
};

#endif

#endif

==> fap-0.9.2.tar.bz2: fap-0.9.2/src/audio/input/wvBackend.h <==
/*
 *  Copyright (C) 2007-2011 Leandro Nini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef WV_H
#define WV_H

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#ifdef HAVE_WAVPACK
extern "C" {
#include <wavpack/wavpack.h>
}

#include "inputBackend.h"
#include <fx.h>

/*****************************************************************/

#include "configFrame.h"

class wvConfig : public configFrame {
	FXDECLARE(wvConfig)

private:
	wvConfig() {};
	wvConfig(const wvConfig&);
	wvConfig& operator=(const wvConfig&);

public:
	wvConfig(FXPacker* win);
	virtual ~wvConfig() {};
};

/*****************************************************************/

class wvBackend : public inputBackend {

private:
	WavpackContext	*_wvContext;
	FXint		*_decodeBuf;
	FXint		_bufOffset;
	FXint		_bufSize;
	FXint		_bps;
	FXint		_channels;
	sample_t	_precision;

private:
	void copyBuffer(FXchar* dest, const FXint* src, size_t length);

private:
	wvBackend();

public:
	~wvBackend();

	static const char name[];

	/// Factory method
	static input* factory() { return new wvBackend(); }

	/// Check if we support ext
	static bool supports(const char* fileName);

	/// Get supported extension
	FXString ext() const;

	/// Open file
	bool open(const FXString& fileName);

	/// Close file
	void close();

	/// Rewind to start
	bool rewind();

	/// Get samplerate
	unsigned int samplerate() const {
		return _wvContext?
			WavpackGetSampleRate(_wvContext):
			0;
	}

	/// Get channels
	unsigned int channels() const {
		return _wvContext?
			WavpackGetReducedChannels(_wvContext):
			0;
	}

	/// Get precision
	sample_t precision() const { return _precision; }

	/// Get fractional scale for fixed point types
	unsigned int fract() const { return (_bps<<3)-1; }

	/// Callback function
	size_t fillBuffer(void* buffer, size_t bufferSize, unsigned int seconds);

	/// Gapless support
	bool gapless() const { return true; };

	/// Open config dialog
	void config(FXPacker* win) { new wvConfig(win); }
};

#endif

#endif
